/* ttt.c - client-server tic-tac-toe game
 *
 * Copyright © 2005 Carl Worth
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * Author: Carl Worth <cworth@cworth.org>
 */

#include <stdio.h>
#include "ttt-board.h"

/* Initialize an empty board. */
void
ttt_board_init (ttt_board_t *board)
{
    int i;
    for (i = 0; i < TTT_BOARD_MAX_CELLS; i++)
    {
	board->cells[i] = TTT_CELL_EMPTY;
    }
}

/* Initialize a board from its string representation.
 *
 * Returns: TTT_BOARD_SUCCESS or TTT_BOARD_INVALID_BOARD if the board
 * string could not be properly parsed.
 */
void
ttt_board_init_from_string (ttt_board_t *board,
			    const char  *s)
{
    /* XXX: NYI */
}

/* Return the string representation of a board.
 *
 * The return value is a malloc()ed string that should be free()ed
 * when no longer needed.
 *
 * Errors: If out-of-memory occurs, this function will not return.
 */
char *
ttt_board_to_string (ttt_board_t *board)
{
    char *s;
    xasprintf (&s, "\r\n" 
	       "%c|%c|%c\r\n"
	       "%c|%c|%c\r\n"
	       "%c|%c|%c",
	       board->cells[0], board->cells[1], board->cells[2], 
	       board->cells[3], board->cells[4], board->cells[5], 
	       board->cells[6], board->cells[7], board->cells[8]); 
    return s;
}

/* Write a string representation of a board to the provided file.
 *
 * Errors: If out-of-memory or a file IO error occurs, this function
 * will not return.
 */
void
ttt_board_write (ttt_board_t *board, FILE *file)
{
    char *s;

    s = ttt_board_to_string (board);

    xfwrite (s, 1, strlen (s) + 1, file);

    free (s);
}

/* Makes a new move in the given board.
 *
 * The move value is a number from 0 to 9 giving the position to be
 * moved as follows:
 * 
 *  0|1|2
 *  3|4|5
 *  6|7|8
 *
 * Returns: 1 if a move isa made succesfully. O if a move is invalid
 * (the given cell is not empty).
 *
 * Bugs: Currently this function always places X for all moves. So,
 * yeah, we'll need to fix that.
 */

 
int ttt_board_make_move (ttt_board_t *board, int move)
{                                    
    
    putchar(move);
    if (board->cells[move] == '_')
    {
	board->cells[move] = 'X';
	return(1);
    }
    else
    {
	return(0);
    }
}
